==> pfqueue-0.4.1.tar.gz: pfqueue-0.4.1/backends/pfq_backend.h <==

/*
 * pfqueue backend
 */

#ifndef PFQ_BACKEND_H
#define PFQ_BACKEND_H

#define BECAPS_MSG_DEL		1	// Can delete messages
#define BECAPS_MSG_HOLD		2	// Can hold (freeze) messages
#define BECAPS_MSG_REQUEUE	4	// Can requeue messages
#define BECAPS_MSG_ENVELOPE	8	// Can extract from/to from envelope
#define BECAPS_MIXED_QUEUE	16	// Backend is single-queue, with status somewhere in some files
#define BECAPS_MSG_LOG		32	// Each message has its own log

#define BUF_SIZE		250

#ifndef FALSE
#define FALSE			0
#endif

int pfb_caps;
int pfb_using_envelope;

// Returns backend id string
const char *pfb_id();

// Returns backend version
const char *pfb_version();

// Init backend
int pfb_init( int argc, char** argv );

// Closes backend
int pfb_close();

// Fill message queue (called from pthread)
int pfb_fill_queue ();

// Retreive from/to/subject fields
int pfb_retr_headers ( const int );

// Retreive message body
int pfb_retr_body ( int, char*, size_t );

// Delete a message
int pfb_message_delete ( int );

// Hold a message
int pfb_message_hold ( int );
// 
// Release a message
int pfb_message_release ( int );

// Requeue a message
int pfb_message_requeue ( int );

// Change current queue
int pfb_set_queue ( int );

// Set/unset use of envelope for from/to retreival
void pfb_use_envelope ( int );

// Get backend caps
int pfb_get_caps();

// Returns the queue name
char* pfb_queue_get_name( int );

// Returns the number of the queues
int pfb_queue_count();

// Ptr to main queue
struct msg_t *my_queue;

// Ptr to backend queue
struct msg_t *ext_queue;

// Sets the number of seconds the queue scanning should not exceed
int dig_limit;

// Time digging was last started
int dig_start;

// Max number of messages to handle
int msg_max;

#endif

==> pfqueue-0.4.2.tar.gz: pfqueue-0.4.2/backends/pfq_backend.h <==

/*
 * pfqueue backend
 */

#ifndef PFQ_BACKEND_H
#define PFQ_BACKEND_H

#define BECAPS_MSG_DEL		1	// Can delete messages
#define BECAPS_MSG_HOLD		2	// Can hold (freeze) messages
#define BECAPS_MSG_REQUEUE	4	// Can requeue messages
#define BECAPS_MSG_ENVELOPE	8	// Can extract from/to from envelope
#define BECAPS_MIXED_QUEUE	16	// Backend is single-queue, with status somewhere in some files
#define BECAPS_MSG_LOG		32	// Each message has its own log

#define BUF_SIZE		250

#ifndef FALSE
#define FALSE			0
#endif

#include "../pfqmessage.h"

int pfb_caps;
int pfb_using_envelope;

// Returns backend id string
const char *pfb_id();

// Returns backend version
const char *pfb_version();

// Init backend
int pfb_init( int argc, char** argv );

// Setup backend
int pfb_setup ( int, int, struct msg_t*, struct be_msg_t* );

// Closes backend
int pfb_close();

// Fill message queue (called from pthread)
int pfb_fill_queue ();

// Retreive from/to/subject fields
int pfb_retr_headers ( const int );

// Retreive message status
int pfb_retr_status ( const int );

// Retreive message body
int pfb_retr_body ( int, char*, size_t );

// Delete a message
int pfb_message_delete ( int );

// Hold a message
int pfb_message_hold ( int );
// 
// Release a message
int pfb_message_release ( int );

// Requeue a message
int pfb_message_requeue ( int );

// Change current queue
int pfb_set_queue ( int );

// Set/unset use of envelope for from/to retreival
void pfb_use_envelope ( int );

// Get backend caps
int pfb_get_caps();

// Returns the queue name
char* pfb_queue_get_name( int );

// Returns the number of the queues
int pfb_queue_count();

// Ptr to main queue
struct be_msg_t *my_queue;

// Ptr to backend queue
struct msg_t *ext_queue;

// Sets the number of seconds the queue scanning should not exceed
int dig_limit;

// Time digging was last started
int dig_start;

// Max number of messages to handle
int msg_max;

#endif
